![PyPI](https://img.shields.io/pypi/v/space-rocks) [![Documentation Status](https://readthedocs.org/projects/rocks/badge/?version=latest)](https://rocks.readthedocs.io/en/latest/?badge=latest) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# rocks

*Disclaimer: The SsODNet service and its database are in an alpha version and under constant revision. The provided values and access methods may change without notice.*

## Features

Command-line exploration and scripted retrieval of asteroid data.

## Install

Install from PyPi using `pip`:

     pip install space-rocks

## Documentation

Check out the documentation at [read-the-docs.io](https://rocks.readthedocs.io/en/latest/).
